@@ -753,6 +753,10 @@ class SoftwareProperties(object):
     if worker:
         # wait for GPG key to be downloaded
         worker.join(30)
+    if self.options and self.options.update:
+        import apt
+        cache = apt.Cache()
+        cache.update(sources_list=new_debsrc_entry.file)
     return True
 
   def remove_source(self, source, remove_source_code=True):
@@ -797,8 +801,6 @@ class SoftwareProperties(object):
 
   def add_key(self, path):
     """Add a gnupg key to the list of trusted software vendors"""
-    if not isinstance(path, str):
-      path = str(path) # allows non-ascii filenames
     if not os.path.exists(path):
         return False
     try:
@@ -809,9 +811,9 @@ class SoftwareProperties(object):
         return False
 
   def add_key_from_data(self, keydata):
-    "Add a gnupg key from a data string (e.g. copy-n-paste)"
+    "Add a gnupg key from a utf-8 data string (e.g. copy-n-paste)"
     tmp = tempfile.NamedTemporaryFile()
-    tmp.write(keydata.encode())
+    tmp.write(keydata.encode("utf-8"))
     tmp.flush()
     return self.add_key(tmp.name)
 
