@@ -1176,7 +1176,9 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                     if (linux_meta and
                         linux_meta not in self.driver_changes):
                         # Install the linux metapackage
-                        self.driver_changes.append(self.apt_cache[linux_meta])
+                        lmp = self.apt_cache[linux_meta]
+                        if not lmp.is_installed:
+                            self.driver_changes.append(lmp)
         except KeyError:
             pass
 
